@@ -609,7 +609,8 @@ pub struct Modal {
     pub close: MessageBlockText,
     #[serde(default, skip_serializing_if = "Vec::is_empty")]
     pub blocks: Vec<InputBlock>,
-    #[serde(default)]
+    // We only need this on deserializing.
+    #[serde(default, skip_serializing)]
     pub state: State,
 }
 
@@ -751,7 +752,11 @@ pub struct ChannelValue {
     pub creator: String,
     #[serde(default)]
     pub last_set: i32,
-    #[serde(default, skip_serializing_if = "String::is_empty")]
+    #[serde(
+        default,
+        skip_serializing_if = "String::is_empty",
+        deserialize_with = "deserialize_null_string::deserialize"
+    )]
     pub value: String,
 }
 
@@ -859,6 +864,10 @@ pub struct InputBlock {
     pub label: Option<MessageBlockText>,
     #[serde(default, skip_serializing_if = "Option::is_none")]
     pub text: Option<MessageBlockText>,
+    #[serde(default, skip_serializing_if = "String::is_empty")]
+    pub hint: String,
+    #[serde(default)]
+    pub optional: bool,
 }
 
 /// Input block element in Slack.
@@ -882,7 +891,11 @@ pub struct SelectInputOption {
     #[serde(default)]
     pub text: MessageBlockText,
 
-    #[serde(default, skip_serializing_if = "String::is_empty")]
+    #[serde(
+        default,
+        skip_serializing_if = "String::is_empty",
+        deserialize_with = "deserialize_null_string::deserialize"
+    )]
     pub value: String,
 }
 
@@ -894,7 +907,11 @@ pub struct ActionBlock {
     #[serde(default)]
     pub text: MessageBlockText,
 
-    #[serde(default, skip_serializing_if = "String::is_empty")]
+    #[serde(
+        default,
+        skip_serializing_if = "String::is_empty",
+        deserialize_with = "deserialize_null_string::deserialize"
+    )]
     pub value: String,
     #[serde(default, skip_serializing_if = "String::is_empty")]
     pub action_id: String,
@@ -949,7 +966,11 @@ pub struct MessageBlockAccessory {
     /// These are for a button.
     #[serde(default, skip_serializing_if = "Option::is_none")]
     pub text: Option<MessageBlockText>,
-    #[serde(default, skip_serializing_if = "String::is_empty")]
+    #[serde(
+        default,
+        skip_serializing_if = "String::is_empty",
+        deserialize_with = "deserialize_null_string::deserialize"
+    )]
     pub value: String,
     #[serde(default, skip_serializing_if = "String::is_empty")]
     pub action_id: String,
@@ -997,8 +1018,15 @@ pub struct MessageAttachment {
 /// A message attachment field in Slack.
 #[derive(Debug, Clone, Deserialize, JsonSchema, Serialize)]
 pub struct MessageAttachmentField {
+    #[serde(default)]
     pub short: bool,
+    #[serde(default, skip_serializing_if = "String::is_empty")]
     pub title: String,
+    #[serde(
+        default,
+        skip_serializing_if = "String::is_empty",
+        deserialize_with = "deserialize_null_string::deserialize"
+    )]
     pub value: String,
 }
 
@@ -1054,8 +1082,15 @@ pub struct UserProfile {
 
 #[derive(Clone, Debug, Serialize, JsonSchema, Deserialize)]
 pub struct UserProfileFields {
+    #[serde(default, skip_serializing_if = "String::is_empty")]
     pub alt: String,
+    #[serde(default, skip_serializing_if = "String::is_empty")]
     pub label: String,
+    #[serde(
+        default,
+        skip_serializing_if = "String::is_empty",
+        deserialize_with = "deserialize_null_string::deserialize"
+    )]
     pub value: String,
 }
 
@@ -1275,8 +1310,7 @@ pub struct InteractivePayload {
     pub channel: Channel,
     #[serde(default)]
     pub message: Message,
-    // We only need this on deserializing.
-    #[serde(default, skip_serializing)]
+    #[serde(default)]
     pub state: State,
     #[serde(default, skip_serializing_if = "String::is_empty")]
     pub response_url: String,
@@ -1307,3 +1341,23 @@ pub struct Container {
     #[serde(default)]
     pub is_app_unfurl: bool,
 }
+
+pub mod deserialize_null_string {
+    use serde::{self, Deserialize, Deserializer};
+
+    // The signature of a deserialize_with function must follow the pattern:
+    //
+    //    fn deserialize<'de, D>(D) -> Result<T, D::Error>
+    //    where
+    //        D: Deserializer<'de>
+    //
+    // although it may also be generic over the output types T.
+    pub fn deserialize<'de, D>(deserializer: D) -> Result<String, D::Error>
+    where
+        D: Deserializer<'de>,
+    {
+        let s = String::deserialize(deserializer).unwrap_or_default();
+
+        Ok(s)
+    }
+}
